## Objective

Run [isort](https://pycqa.github.io/isort/) on your Python code to automatically sort and organize
your imports. isort separates imports into sections and by type. It's a helpful tool to ensure that
your code remains clean and readable.

## How to use it

1. Configure the `pyproject.toml` or `.isort.cfg` file in your repository's root directory with your
   desired rules.
2. Include the isort template in your CI/CD configuration (see quick use above).
3. If you need to customize the job, check
   the [jobs customization](https://docs.r2devops.io/get-started/use-templates/#job-templates-customization).

## Variables

| Name                | Description                                                                                                                                                   | Default                              |
|---------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------|
| `PROJECT_PATH`      | The path to the project root directory.                                                                                                                       | `"."`                                |
| `IMAGE_TAG`         | The default tag for the docker image. See [Python Docker Official Image](https://hub.docker.com/_/python) for supported tags and respective Dockerfile links. | `"latest"`                           |
| `PYTHON_SETUP`      | Bash commands to setup your python environment.                                                                                                               | `"pip install isort"`                |

## Global Configuration of isort

To add configuration to `isort` shared with any other usage of isort (such as manual run,
pre-commit, etc), you can use `pyproject.toml` configuration file or a dedicated `.isort.cfg`. Learn
more about [isort configuration](https://pycqa.github.io/isort/docs/configuration/config_files.html)
files.

## Add a [![Imports: isort](https://img.shields.io/badge/imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/) badge to your project README.md

To display the use of isort in your project, you can add the following badge to your README.md:

```markdown
[![Imports: isort](https://img.shields.io/badge/imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
```
