## Objective

Run [Ruff](https://github.com/astral-sh/ruff), an extremely fast Python linter, on your Python
code. This tool is written in Rust, and it is designed to quickly analyze your Python code to detect
various syntax and stylistic errors.

## How to use it

1. Configure the `pyproject.toml` file in your repository's root directory with your desired rules.
2. Include the Ruff template in your GitLab CI/CD configuration.
3. If you need to customize the job, refer to
   the [jobs customization](https://docs.r2devops.io/get-started/use-templates/#job-templates-customization)
   documentation.

## Variables

| Name                | Description                                                                                                                                                   | Default                              |
|---------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------|
| `PROJECT_PATH`      | The path to the project root directory.                                                                                                                       | `"."`                                |
| `IMAGE_TAG`         | The default tag for the docker image. See [Python Docker Official Image](https://hub.docker.com/_/python) for supported tags and respective Dockerfile links. | `"latest"`                           |
| `PYTHON_SETUP`      | Bash commands to setup your python environment.                                                                                                               | `"pip install ruff"`                 |

### Global Configuration of Ruff

To add configuration to `ruff` that is shared with any other usage of Ruff (such as manual run,
pre-commit, etc), you can use a `pyproject.toml`, `ruff.toml`, or `.ruff.toml` configuration file in
your project's root directory. Learn more
about [ruff configuration](https://beta.ruff.rs/docs/configuration/) files.

## Add an official [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) badge to your project README.md

To display the use of Ruff in your project, you can add the following badge to your README.md:

```markdown
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
```

A more "classic" version of the badge ([![Code style: Ruff](https://img.shields.io/badge/Linter-Ruff-blue)](https://github.com/astral-sh/ruff)) is also available:

```markdown
[![Ruff](https://img.shields.io/badge/Linter-Ruff-blue)](https://github.com/astral-sh/ruff)
```
